import { ElementRef, TemplateRef, EmbeddedViewRef, ViewContainerRef, EventEmitter } from '@angular/core';
import { RadSideDrawer } from 'nativescript-ui-sidedrawer';
import * as i0 from "@angular/core";
export interface ItemEventArgs {
    object: any;
    view: EmbeddedViewRef<any>;
    returnValue?: boolean;
}
/**
 * This is the SideDrawer component. It separates your mobile app's screen
 * into a main part and a menu part whereby the menu part is shown upon a swipe
 * gesture using a transition effect.
 */
export declare class RadSideDrawerComponent {
    elementRef: ElementRef;
    private viewContainer;
    sideDrawer: RadSideDrawer;
    mainTemplate: TemplateRef<ElementRef>;
    drawerTemplate: TemplateRef<ElementRef>;
    private _drawerContentSize;
    private _gesturesEnabled;
    private _drawerTransition;
    private _drawerLocation;
    drawerOpening: EventEmitter<any>;
    drawerOpen: EventEmitter<any>;
    drawerClosing: EventEmitter<any>;
    drawerClosed: EventEmitter<any>;
    /**
     * [Deprecated: Please use the 'drawerTransition' property instead].
     */
    set transition(transition: any);
    constructor(elementRef: ElementRef, viewContainer: ViewContainerRef);
    get nativeElement(): RadSideDrawer;
    /**
     * Defines either the width or the height
     * of the menu pane depending on the location of the SideDrawer.
     * Top or Bottom - height, Right or Left - width.
     */
    set drawerContentSize(value: number);
    set gesturesEnabled(value: boolean);
    set drawerTransition(value: string);
    set drawerLocation(value: string);
    private updateDrawerLocation;
    private updateDrawerTransition;
    private updateGesturesEnabled;
    private updateContentSize;
    static ɵfac: i0.ɵɵFactoryDeclaration<RadSideDrawerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<RadSideDrawerComponent, "RadSideDrawer", never, { "transition": "transition"; }, { "drawerOpening": "drawerOpening"; "drawerOpen": "drawerOpen"; "drawerClosing": "drawerClosing"; "drawerClosed": "drawerClosed"; }, never, ["*"], false, never>;
}
/**
 * Directive identifying the drawer content.
 */
export declare class TKDrawerContentDirective {
    private _elementRef;
    constructor(_elementRef: ElementRef);
    static ɵfac: i0.ɵɵFactoryDeclaration<TKDrawerContentDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TKDrawerContentDirective, "[tkDrawerContent]", never, {}, {}, never, never, false, never>;
}
/**
 * Directive identifying the main content.
 */
export declare class TKMainContentDirective {
    private _elementRef;
    constructor(_elementRef: ElementRef);
    static ɵfac: i0.ɵɵFactoryDeclaration<TKMainContentDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TKMainContentDirective, "[tkMainContent]", never, {}, {}, never, never, false, never>;
}
/**
 * Directives identifying the RadSideDrawer.
 */
export declare const SIDEDRAWER_DIRECTIVES: (typeof RadSideDrawerComponent | typeof TKDrawerContentDirective | typeof TKMainContentDirective)[];
/**
 * NgModule containing all of the RadSideDrawer directives.
 */
export declare class NativeScriptUISideDrawerModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<NativeScriptUISideDrawerModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<NativeScriptUISideDrawerModule, [typeof RadSideDrawerComponent, typeof TKDrawerContentDirective, typeof TKMainContentDirective], never, [typeof RadSideDrawerComponent, typeof TKDrawerContentDirective, typeof TKMainContentDirective]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<NativeScriptUISideDrawerModule>;
}
